@@ -162,16 +162,13 @@ static struct PyModuleDef moduledef = {PyModuleDef_HEAD_INIT,
                                        NULL};
 
 // Define macro to make sure symbol is exported
-// TODO: Switch to C23 native
-#if defined(_WIN32) || defined(WIN32)
-// Note: actually gcc and intel seem to also supports this syntax.
-#ifdef _MSC_VER
-#define EXPORT __declspec(dllexport)
+// When compiling define API for export
+#if defined(_MSC_VER)
+    // On windows the API must be explicitly marked for export/import
+    #define EXPORT __declspec(dllexport)
 #else
-#define EXPORT __attribute__((dllexport))
-#endif
-#else
-#define EXPORT __attribute__((visibility("default")))
+    // On Unix this is not necessary
+    #define EXPORT __attribute__((visibility("default")))
 #endif
 
 EXPORT PyObject *PyInit__spglib(void) {
