@@ -35,13 +35,16 @@
 #ifndef __delaunay_H__
 #define __delaunay_H__
 
+#include "base.h"
 #include "mathfunc.h"
 
-int del_delaunay_reduce(double lattice_new[3][3], const double lattice[3][3],
-                        const double symprec);
-int del_layer_delaunay_reduce(double min_lattice[3][3],
-                              const double lattice[3][3],
-                              const int aperiodic_axis, const double symprec);
+SPG_API_TEST int del_delaunay_reduce(double lattice_new[3][3],
+                                     double const lattice[3][3],
+                                     double const symprec);
+SPG_API_TEST int del_layer_delaunay_reduce(double min_lattice[3][3],
+                                           double const lattice[3][3],
+                                           int const aperiodic_axis,
+                                           double const symprec);
 
 // @brief Delaunay reduction for monoclinic/oblique or monoclinic/rectangular
 // @param[out] red_lattice
@@ -56,9 +59,9 @@ int del_layer_delaunay_reduce(double min_lattice[3][3],
 //       k(=aperiodic_axis)}. j and k are delaunay reduced, which can be
 //       incomplete for Monoclinic/Rectangular
 int del_layer_delaunay_reduce_2D(double min_lattice[3][3],
-                                 const double lattice[3][3],
-                                 const int unique_axis,
-                                 const int aperiodic_axis,
-                                 const double symprec);
+                                 double const lattice[3][3],
+                                 int const unique_axis,
+                                 int const aperiodic_axis,
+                                 double const symprec);
 
 #endif
